<?php

$LANG = array(

'L_MENU'											=> 'Menü',
'L_UNKNOWN_ERROR'									=> 'Unbekannter Fehler',
'L_CONFIRM_DELETE'									=> 'Löschen bestätigen?',
'L_SAVE_FILE'										=> 'Speichern Sie die Datei',
'L_SAVE_FILE_SUCCESSFULLY'							=> 'Datei erfolgreich gespeichert',
'L_SAVE_FILE_ERROR'									=> 'Fehler beim Speichern der Datei für',
'L_REPLY'											=> 'Antworten',
'L_REPLY_TO'										=> 'Antworten',
'L_CANCEL'											=> 'Abbrechen',
'L_DELETE'											=> 'Löschen',
'L_DELETE_FILE' 				    				=> 'Datei löschen',
'L_DELETE_FOLDER'				   					=> 'Verzeichnis löschen',
'L_THUMBNAIL'										=> 'Vorschaubild (optional)',
'L_THUMBNAIL_SELECTION'								=> 'Bild auswählen',
'L_THUMBNAIL_TITLE'									=> 'Bildtitel (optional)',
'L_THUMBNAIL_ALT'									=> 'Alternativtext des Bildes (optional)',
'L_SAVE_SUCCESSFUL'									=> 'Daten erfolgreich gespeichert',
'L_SAVE_ERR'										=> 'Fehler während des Speicherns',
'L_NO_ENTRY'										=> 'Datenzugriff verboten',
'L_ERR_USER_EMPTY'									=> 'Bitte Benutzernamen eingeben',
'L_ERR_PASSWORD_EMPTY'								=> 'Bitte ein Passwort eingeben',
'L_ERR_PASSWORD_EMPTY_CONFIRMATION'					=> 'Ungültiges oder leeres Passwort',
'L_ERR_INVALID_EMAIL'								=> 'Ungültige E-Mail-Adresse',
'L_ERR_INVALID_SITE'								=> 'Ungültige Adresse der Website',
'L_ERR_INVALID_ARTICLE_IDENT'						=> 'Ungültige Artikel-ID!',
'L_DEFAULT_NEW_CATEGORY_URL'						=> 'neue-kategorie',
'L_DEFAULT_NEW_STATIC_URL'							=> 'neue-seite',
'L_DEFAULT_NEW_ARTICLE_URL'							=> 'neuer-artikel',
'L_ARTICLE_SAVE_SUCCESSFUL'							=> 'Artikel erfolgreich angelegt',
'L_ARTICLE_MODIFY_SUCCESSFUL'						=> 'Artikel erfolgreich aktualisiert',
'L_ARTICLE_DELETE_SUCCESSFUL'						=> 'Artikel erfolgreich gelöscht',
'L_ARTICLE_SAVE_ERR'								=> 'Fehler beim Speichern des Artikels.',
'L_ARTICLE_DELETE_ERR'								=> 'Fehler beim Löschen des Artikels.',
'L_ERR_UNKNOWN_COMMENT'								=> 'Der angeforderte Kommentar existiert nicht oder nicht mehr',
'L_COMMENT_SAVE_SUCCESSFUL'							=> 'Kommentar erfolgreich geändert',
'L_COMMENT_UPDATE_ERR'								=> 'Fehler während der Kommentaraktualisierung',
'L_COMMENT_DELETE_SUCCESSFUL'						=> 'Kommentar erfolgreich gelöscht',
'L_COMMENT_DELETE_ERR'								=> 'Fehler beim Löschen.',
'L_COMMENT_VALIDATE_SUCCESSFUL'						=> 'Validierung erfolgreich',
'L_COMMENT_VALIDATE_ERR'							=> 'Fehler bei der Validierung.',
'L_COMMENT_MODERATE_SUCCESSFUL'						=> 'Durch den Moderator akzeptiert',
'L_COMMENT_MODERATE_ERR'							=> 'Fehler oder durch Moderator abgelehnt',
'L_COMMENT_WRITTEN_BY'								=> 'Geschrieben von',
'L_PLXMEDIAS_MEDIAS_FOLDER_ERR'						=> 'Der Ordner "Medias" konnte für diesen Benutzer nicht angelegt werden',
'L_PLXMEDIAS_ROOT'									=> 'Grundverzeichnis',
'L_PLXMEDIAS_NEW_FOLDER_ERR'						=> 'Der Ordner konnte nicht angelegt werden',
'L_PLXMEDIAS_NEW_FOLDER_SUCCESSFUL'					=> 'Ordner erfolgreich angelegt',
'L_PLXMEDIAS_NEW_FOLDER_EXISTS'						=> 'Dieser Ordner existiert bereits',
'L_PLXMEDIAS_DEL_FOLDER_ERR'						=> 'Fehler beim Löschen den Ordners',
'L_PLXMEDIAS_DEL_FOLDER_SUCCESSFUL'					=> 'Der Ordner wurde erfolgreich gelöscht',
'L_PLXMEDIAS_WRONG_FILEFORMAT'						=> 'Dieser Dateityp ist nicht erlaubt',
'L_PLXMEDIAS_WRONG_FILESIZE'						=> 'Die Datei ist größer als ',
'L_PLXMEDIAS_UPLOAD_ERR'							=> 'Fehler beim Hochladen der Datei',
'L_PLXMEDIAS_UPLOAD_SUCCESSFUL'						=> 'Die Datei wurde erfolgreich hochgeladen',
'L_PLXMEDIAS_UPLOADS_ERR'							=> 'Fehler beim Hochladen von Dateien',
'L_PLXMEDIAS_UPLOADS_SUCCESSFUL'					=> 'Dateien wurden erfolgreich hochgeladen',
'L_PLXMEDIAS_DELETE_FILES_SUCCESSFUL'				=> 'Dateien wurden erfolgreich entfernt',
'L_PLXMEDIAS_DELETE_FILES_ERR'						=> 'Fehler beim Löschen der Dateien',
'L_PLXMEDIAS_DELETE_FILE_SUCCESSFUL'				=> 'Die Datei wurde erfolgreich gelöscht',
'L_PLXMEDIAS_DELETE_FILE_ERR'						=> 'Fehler beim Löschen der Datei',
'L_PLXMEDIAS_MOVE_FILES_ERR'						=> 'Fehler beim Verschieben der Dateien',
'L_PLXMEDIAS_MOVE_FILE_ERR'							=> 'Fehler beim Verschieben der Datei',
'L_PLXMEDIAS_MOVE_FILES_SUCCESSFUL'					=> 'Dateien wurden erfolgreich verschoben',
'L_PLXMEDIAS_MOVE_FILE_SUCCESSFUL'					=> 'Datei wurde erfolgreich verschoben',
'L_PLXMEDIAS_MOVE_FOLDER'							=> 'Verschieben',
'L_PLXMEDIAS_RECREATE_THUMB_ERR'					=> 'Fehler beim Erstellen der Miniaturansicht',
'L_PLXMEDIAS_RECREATE_THUMBS_ERR'					=> 'Fehler beim Erstellen des Miniaturansichten',
'L_PLXMEDIAS_RECREATE_THUMB_SUCCESSFUL'				=> 'Miniaturansicht erfolgreich erstellt',
'L_PLXMEDIAS_RECREATE_THUMBS_SUCCESSFUL'			=> 'Miniaturansichten erfolgreich erstellt',
'L_DEFAULT_NEW_ARTICLE_TITLE'						=> 'Neuer Artikel',
'L_ERR_INVALID_PUBLISHING_DATE'						=> 'Ungültiges Erscheinungsdatum.',
'L_ERR_UNKNOWN_ARTICLE'								=> 'Der angeforderte Artikel existiert nicht oder nicht mehr!',
'L_ERR_FORBIDDEN_ARTICLE'							=> 'Sie haben keine Berechtigung, auf diesen Artikel zuzugreifen!',
'L_BACK_TO_ARTICLES'								=> 'Zurück zur Artikelliste',
'L_ARTICLE_EDITING'									=> 'Artikel bearbeiten',
'L_ARTICLE_TITLE'									=> 'Titel',
'L_ARTICLE_LIST_AUTHORS'							=> 'Autor',
'L_HEADLINE_FIELD'									=> 'Vorspann (optional)',
'L_CONTENT_FIELD'									=> 'Inhalt',
'L_LINK_FIELD'										=> 'Link zum Artikel',
'L_LINK_ACCESS'										=> 'Zum Artikel',
'L_LINK_VIEW'										=> 'sehen',
'L_ARTICLE_STATUS'									=> 'Status',
'L_DRAFT'											=> 'Entwurf',
'L_PUBLISHED'										=> 'Publiziert',
'L_AWAITING'										=> 'Erwartet Moderation',
'L_ARTICLE_DATE'									=> 'Erscheinungsdatum',
'L_NOW'												=> 'jetzt',
'L_ARTICLE_CATEGORIES'								=> 'Kategorien',
'L_CATEGORY_HOME_PAGE'								=> 'Homepage',
'L_NEW_CATEGORY'									=> 'Neue Kategorie',
'L_ARTICLE_TAGS_FIELD'								=> 'Schlagworte',
'L_ARTICLE_TAGS_FIELD_TITLE'						=> 'Trennen Sie Schlagorte mit Komma',
'L_ARTICLE_TOGGLER_TITLE'							=> 'Schlagwortliste',
'L_NO_TAG'											=> 'Kein Schlagwort',
'L_ALLOW_COMMENTS'									=> 'Kommentare erlauben',
'L_ARTICLE_URL_FIELD'								=> 'URL',
'L_ARTICLE_URL_FIELD_TITLE'							=> 'URL wird bei der Artikelerstellung automatisch generiert',
'L_ARTICLE_TEMPLATE_FIELD'							=> 'Template',
'L_ARTICLE_MANAGE_COMMENTS'							=> 'Kommentare verwalten',
'L_ARTICLE_MANAGE_COMMENTS_TITLE'					=> 'Kommentare dieses Artikels verwalten',
'L_ARTICLE_NEW_COMMENT'								=> 'Kommentar schreiben',
'L_ARTICLE_NEW_COMMENT_TITLE'						=> 'Einen Kommentar zu diesem Artikel schreiben',
'L_ARTICLE_DELETE_CONFIRM'							=> 'Diesen Artikel löschen?',
'L_ARTICLE_PREVIEW_BUTTON'							=> 'Vorschau',
'L_ARTICLE_DRAFT_BUTTON'							=> 'Als Entwurf speichern',
'L_ARTICLE_PUBLISHING_BUTTON'						=> 'Publizieren',
'L_ARTICLE_MODERATE_BUTTON'							=> 'Zur Moderation einreichen',
'L_ARTICLE_OFFLINE_BUTTON'							=> 'Offline stellen',
'L_ARTICLE_UPDATE_BUTTON'							=> 'Speichern',
'L_CATEGORY_ADD_BUTTON'								=> 'Hinzufügen',
'L_ARTICLE_META_DESCRIPTION'						=> 'META Tag "description" (optional)',
'L_ARTICLE_META_KEYWORDS'							=> 'META Tag "keywords" (optional)',
'L_ARTICLE_TITLE_HTMLTAG'							=> 'Title-Tag Inhalte (optional)',
'L_ARTICLE_CHAPO_HIDE'								=> 'verbergen',
'L_ARTICLE_CHAPO_DISPLAY'							=> 'anzeigen',
'L_ARTICLE'											=> 'artikel',
'L_ARTICLE_ID'										=> 'ID',
'L_AUTH_PAGE_TITLE'									=> 'Anmeldung',
'L_LOGOUT_SUCCESSFUL'								=> 'Sie wurden erfolgreich abgemeldet',
'L_LOGIN_PAGE'										=> 'Administrator Anmeldung',
'L_AUTH_LOGIN_FIELD'								=> 'Benutzer',
'L_AUTH_PASSWORD_FIELD'								=> 'Passwort',
'L_SUBMIT_BUTTON'									=> 'Anmelden',
'L_ERR_WRONG_PASSWORD'								=> 'Benutzername und/oder Passwort sind falsch',
'L_POWERED_BY'										=> 'Generiert von <a href="http://www.pluxml.org">PluXml</a>',

'L_CAT_TITLE'										=> 'Kategorien erstellen/ändern',
'L_CAT_LIST_ID'										=> 'ID',
'L_CAT_LIST_ACTIVE'									=> 'Aktiv',
'L_CAT_LIST_NAME'									=> 'Name der Kategorie',
'L_CAT_LIST_URL'									=> 'URL',
'L_CAT_LIST_SORT'									=> 'Sortierung der Artikel',
'L_CAT_LIST_BYPAGE'									=> 'Artikel/Seite',
'L_CAT_LIST_ORDER'									=> 'Reihenfolge',
'L_CAT_LIST_MENU'									=> 'Menü',
'L_CATEGORY'										=> 'Kategorie',
'L_DISPLAY'											=> 'Anzeigen',
'L_HIDE'											=> 'Verstecken',
'L_OPTIONS'											=> 'Optionen',
'L_FOR_SELECTION'									=> 'Aktion auswählen...',
'L_CAT_APPLY_BUTTON'								=> 'Änderungen speichern',
'L_CAT_UNKNOWN'										=> 'Unbekannte Kategorie',
'L_EDITCAT_PAGE_TITLE'								=> 'Kategorieoptionen ändern',
'L_EDITCAT_DISPLAY_HOMEPAGE'						=> 'Zeige Artikel in dieser Kategorie auf der Startseite',
'L_EDITCAT_DESCRIPTION'								=> 'Beschreibung',
'L_EDITCAT_TEMPLATE'								=> 'Vorlage',
'L_EDITCAT_BACK_TO_PAGE'							=> 'Zurück zur Liste der Kategorien',
'L_EDITCAT_UPDATE'									=> 'Kategorie aktualisieren',
'L_EDITCAT_TITLE_HTMLTAG'							=> 'Title-Tag Inhalte (optional)',
'L_EDITCAT_META_DESCRIPTION'						=> 'META Tag "description" - Inhalt für diese Kategorie (optional)',
'L_EDITCAT_META_KEYWORDS'							=> 'META Tag "keywords" - Inhalt für diese Kategorie (optional)',
'L_COMMENT_ORPHAN'									=> 'keinen Artikel',
'L_COMMENT_ORPHAN_STATUS'							=> 'verwaist (Sie sollten diesen Kommentar löschen)',
'L_COMMENT_ARTICLE_LINKED'							=> 'Artikel',
'L_COMMENT_ARTICLE_LINKED_TITLE'					=> 'Artikel zu diesem Kommentar',
'L_COMMENT_OFFLINE'									=> 'Offline',
'L_COMMENT_ONLINE'									=> 'Online',
'L_COMMENT_ONLINE_TITLE'							=> 'Liste der publizierten Kommentare',
'L_BACK_TO_ARTICLE_COMMENTS'						=> 'Zurück zur Liste der Kommentare dieses Artikels',
'L_BACK_TO_COMMENTS'								=> 'Zurück zur Liste der Kommentare',
'L_COMMENT_EDITING'									=> 'Kommentar bearbeiten',
'L_COMMENT_AUTHOR_FIELD'							=> 'Autor',
'L_COMMENT_TYPE_FIELD'								=> 'Art des Kommentars',
'L_COMMENT_DATE_FIELD'								=> 'Datum und Zeitpunkt der veröffentlichung',
'L_COMMENT_IP_FIELD'								=> 'IP',
'L_COMMENT_SITE_FIELD'								=> 'Website',
'L_COMMENT_EMAIL_FIELD'								=> 'E-mail',
'L_COMMENT_STATUS_FIELD'							=> 'Status',
'L_COMMENT_LINKED_ARTICLE_FIELD'					=> 'Bezieht sich auf Artikel',
'L_COMMENT_ARTICLE_FIELD'							=> 'Kommentar',
'L_COMMENT_DELETE_CONFIRM'							=> 'Diesen Kommentar löschen?',
'L_COMMENT_PUBLISH_BUTTON'							=> 'Publizieren bestätigen',
'L_COMMENT_OFFLINE_BUTTON'							=> 'Offline stellen',
'L_COMMENT_ANSWER_BUTTON'							=> 'Antworten',
'L_COMMENT_UPDATE_BUTTON'							=> 'Aktualisieren',
'L_ERR_ANSWER_UNKNOWN_COMMENT'						=> 'Der Kommentar, auf den Sie antworten wollen, existiert nicht oder nicht mehr!',
'L_ERR_ANSWER_OFFLINE_COMMENT'						=> 'Der Kommentar ist offline, Antworten ist nicht möglich!',
'L_ERR_COMMENT_UNKNOWN_ARTICLE'						=> 'Der gefragte Artikel existiert nicht oder nicht mehr. Sie können keinen Kommentar erstellen!',
'L_ERR_CREATING_COMMENT'							=> 'Es gab einen Fehler beim Erstellen des Kommentars',
'L_CREATING_COMMENT_SUCCESSFUL'						=> 'Der Kommentar wurde erfolgreich erstellt',
'L_CREATE_NEW_COMMENT'								=> 'Kommentar schreiben',
'L_COMMENT_SAVE_BUTTON'								=> 'Speichern',
'L_ARTICLE_COMMENTS_LIST'							=> 'Kommentare dieses Artikels (neueste zuerst)',
'L_COMMENT_ANSWER_TITLE'							=> 'Auf diesen Kommentar antworten',
'L_COMMENT_ANSWER'									=> 'Antworten',
'L_COMMENTS_ONLINE_LIST'							=> 'Liste der veröffentlichten Kommentare',
'L_COMMENTS_ALL_LIST'								=> 'Liste aller Kommentare',
'L_COMMENT_SET_ONLINE'								=> 'Online nehmen',
'L_COMMENT_SET_OFFLINE'								=> 'Offline nehmen',
'L_COMMENT_NEW_COMMENT_TITLE'						=> 'Einen neuen Kommentar für diesen Artikel schreiben',
'L_COMMENT_NEW_COMMENT'								=> 'Einen neuen Kommentar schreiben',
'L_COMMENTS_ARTICLE_SCOPE'							=> 'Artikel',
'L_COMMENTS_GLOBAL_SCOPE'							=> 'ganze Website',
'L_COMMENTS_OFFLINE_LIST'							=> 'Liste der wartenden Kommentare ',
'L_COMMENTS_LIST_DATE'								=> 'Datum',
'L_COMMENTS_LIST_AUTHOR'							=> 'Autor',
'L_COMMENTS_LIST_MESSAGE'							=> 'Nachricht',
'L_COMMENTS_LIST_ACTION'							=> 'Aktion',
'L_COMMENT_EDIT'									=> 'editieren',
'L_COMMENT_EDIT_TITLE'								=> 'Diesen Kommentar bearbeiten',
'L_COMMENT_DELETE'									=> 'Löschen',
'L_COMMENT_OFFLINE_FEEDS_TITLE'						=> 'Feed der Offline-Kommentare (Rss)',
'L_COMMENT_OFFLINE_FEEDS'							=> 'Offline Kommentare',
'L_COMMENT_ONLINE_FEEDS_TITLE'						=> 'Feed der Online-Kommentare (Rss)',
'L_COMMENT_ONLINE_FEEDS'							=> 'Online-Kommentare',
'L_COMMENTS_PRIVATE_FEEDS'							=> 'Private Feed',
'L_ARTICLES_FILTER_BUTTON'							=> 'Filtern',
'L_CATEGORIES_TABLE'								=> 'Kategorien',
'L_SPECIFIC_CATEGORIES_TABLE'						=> 'Exakter Ort',
'L_ALL_ARTICLES_CATEGORIES_TABLE'					=> 'Alle Artikel',
'L_ARTICLES_LIST'									=> 'Artikelliste',
'L_ARTICLE_LIST_DATE'								=> 'Datum',
'L_ARTICLE_LIST_TITLE'								=> 'Titel',
'L_ARTICLE_LIST_CATEGORIES'							=> 'Kategorie',
'L_ARTICLE_LIST_NBCOMS'								=> 'Kom. Nummer',
'L_ARTICLE_LIST_AUTHOR'								=> 'Autor',
'L_ARTICLE_LIST_ACTION'								=> 'Aktion',
'L_CATEGORY_HOME'									=> 'Homepage',
'L_CATEGORY_DRAFT'									=> 'Entwurf',
'L_ARTICLE_VIEW'									=> 'Ansehen',
'L_ARTICLE_VIEW_TITLE'								=> 'Den Artikel auf der Website ansehen',
'L_ARTICLE_EDIT'									=> 'editieren',
'L_ARTICLE_EDIT_TITLE'								=> 'Diesen Artikel bearbeiten',
'L_NEW_COMMENTS_TITLE'								=> 'Wartende Kommentare',
'L_VALIDATED_COMMENTS_TITLE'						=> 'Publizierte Kommentare',
'L_NO_ARTICLE'										=> 'Kein(e) Artikel',
'L_ARTICLES_SEARCH_BUTTON'							=> 'Suche',
'L_ARTICLES_ALL_CATEGORIES'							=> 'Alle Kategorien ...',
'L_ALL'												=> 'Alle',
'L_ALL_PUBLISHED'									=> 'Veröffentlicht',
'L_ALL_DRAFTS'										=> 'Entwürfe',
'L_ALL_AWAITING_MODERATION'							=> 'erwarten Moderation',
'L_MEDIAS_DELETE_FOLDER'							=> 'Ordner löschen',
'L_MEDIAS_DELETE_FOLDER_CONFIRM'					=> 'Ordner inkl. Inhalt löschen %s?',
'L_MEDIAS_NO_FILE'									=> 'Keine Datei(en)',
'L_MEDIAS_FILENAME'									=> 'Dateiname',
'L_MEDIAS_ADD_FILE'									=> 'Dateien hochladen',
'L_MEDIAS_BACK'										=> 'Zurück',
'L_MEDIAS_TITLE'									=> 'Datei und Medienverwaltung',
'L_MEDIAS_IMAGES'									=> 'Bilder',
'L_MEDIAS_DOCUMENTS'								=> 'Dokumente',
'L_MEDIAS_CREATE_FOLDER'							=> 'Ordner erstellen',
'L_MEDIAS_SUBMIT_FILE'								=> 'Abschicken',
'L_MEDIAS_MAX_UPOLAD_FILE'							=> 'Maximale Größe der Datei',
'L_MEDIAS_DIRECTORY'								=> 'Ort',
'L_MEDIAS_FOLDER'									=> 'Datei',
'L_MEDIAS_NEW_FOLDER'								=> 'Neuer Ordner',
'L_MEDIAS_FILESIZE'									=> 'Größe',
'L_MEDIAS_DATE'										=> 'Datum',
'L_MEDIAS_DIMENSIONS'								=> 'Abmessungen',
'L_MEDIAS_RESIZE'									=> 'Bilder skalieren',
'L_MEDIAS_RESIZE_NO'								=> 'Originalgröße',
'L_MEDIAS_THUMBS'									=> 'Miniaturansicht erstellen',
'L_MEDIAS_THUMBS_NONE'								=> 'Kein Bild',
'L_MEDIAS_MODIFY'									=> 'Bearbeiten',
'L_MEDIAS_THUMB'									=> 'Miniaturansicht',
'L_MEDIAS_EXTENSION'								=> 'Erweiterung',
'L_MEDIAS_ADD'										=> 'Hinzufügen',
'L_MEDIAS_ALIGNMENT'								=> 'Ausrichtung',
'L_MEDIAS_ALIGN_NONE'								=> 'Nein',
'L_MEDIAS_ALIGN_LEFT'								=> 'Links',
'L_MEDIAS_ALIGN_CENTER'								=> 'Center',
'L_MEDIAS_ALIGN_RIGHT'								=> 'Rechts',
'L_MEDIAS_RECREATE_THUMB'							=> 'Miniaturansicht neu erstellen',
'L_SORT_ASCENDING_DATE'								=> 'Datum aufsteigend',
'L_SORT_DESCENDING_DATE'							=> 'Datum absteigend',
'L_SORT_ALPHABETICAL'								=> 'alphabetisch',
'L_OK'												=> 'Ok',
'L_YES'												=> 'Ja',
'L_NO'												=> 'Nein',
'L_NONE1'											=> 'kein',
'L_NONE2'											=> 'kein',
'L_CONFIG_VIEW_FIELD'								=> 'Darstellungsoptionen',
'L_CONFIG_VIEW_SKIN_SELECT'							=> 'Themenauswahl',
'L_CONFIG_VIEW_FILES_EDIT_TITLE'					=> 'Themendateien editieren',
'L_CONFIG_VIEW_FILES_EDIT'							=> 'Themendateien editieren',
'L_CONFIG_VIEW_SORT'								=> 'Artikelsortierung',
'L_CONFIG_VIEW_BYPAGE'								=> 'Angezeigte Artikel pro Seite',
'L_CONFIG_VIEW_BYPAGE_ARCHIVES'						=> 'Angezeigte Artikel pro Seite (Archiv)',
'L_CONFIG_VIEW_BYPAGE_ADMIN'						=> 'Angezeigte Artikel pro Seite (Admin)',
'L_CONFIG_VIEW_SORT_COMS'							=> 'Kommentarsortierung',
'L_CONFIG_VIEW_BYPAGE_ADMIN_COMS'					=> 'Angezeigte Kommentare pro Seite (Admin)',
'L_CONFIG_VIEW_IMAGES'								=> 'Bildgröße (Breite x Höhe)',
'L_CONFIG_VIEW_THUMBS'								=> 'Größe der Miniaturansicht (Breite x Höhe)',
'L_CONFIG_VIEW_HOMESTATIC'							=> 'Eine statische Seite als Homepage verwenden',
'L_CONFIG_VIEW_HOMESTATIC_ACTIVE'					=> 'Achtung! Diese Seite ist inaktiv',
'L_CONFIG_VIEW_PLUXML_RESSOURCES'					=> 'Themen von <a href="http://ressources.pluxml.org">ressources.pluxml.org</a> laden.',
'L_CONFIG_VIEW_BYPAGE_FEEDS'						=> 'Anzahl der angezeigten Artikel/Kommentare im RSS Feed',
'L_CONFIG_VIEW_FEEDS_HEADLINE'						=> 'Im RSS Feed nur Vorspann des Artikels zeigen',
'L_CONFIG_VIEW_FEEDS_HEADLINE_HELP'					=> 'Wenn der Vorspann leer ist, Inhalt anzeigen',
'L_CONFIG_VIEW_FEEDS_FOOTER'						=> 'Text am Artikelende jedes RSS Feeds',
'L_CONFIG_VIEW_UPDATE'								=> 'Änderungen speichern',
'L_CONFIG_VIEW_DISPLAY_EMPTY_CAT'					=> 'Leere Kategorien (ohne Artikel) anzeigen',
'L_CONFIG_HOMETEMPLATE'								=> 'Vorlage der Homepage',
'L_CONFIG_ADVANCED_DESC'							=> 'Erweiterte Einstellungen',
'L_CONFIG_ADVANCED_URL_REWRITE'						=> 'Adressweiterleitung aktivieren (URL rewrite)',
'L_CONFIG_ADVANCED_URL_REWRITE_ALERT'				=> 'Achtung! Es ist bereits eine .htaccess Datei im Grundverzeichnis von PluXml vorhanden. Diese Datei wird beim Aktivieren modifiziert.',
'L_CONFIG_ADVANCED_GZIP'							=> 'GZIP Kompression aktivieren',
'L_CONFIG_ADVANCED_GZIP_HELP'						=> 'Komprimierung spart Bandreite, erhöht aber die Prozessorauslastung des Servers.',
'L_CONFIG_ADVANCED_CAPCHA'							=> 'ANTI-SPAM Kontrolle aktivieren',
'L_CONFIG_ADVANCED_ADMIN_KEY'						=> 'Adminschlüssel (private URLs)',
'L_CONFIG_ADVANCED_KEY_HELP'						=> 'Feld leeren um neuen Schlüssel zu generieren',
'L_CONFIG_ADVANCED_USERFOLDERS'						=> 'Verwenden Sie unterschiedliche Medien Ordner für jeden Benutzer',
'L_HELP_SLASH_END'									=> 'Schrägstrich (Slash) am Ende nicht vergessen!',
'L_CONFIG_ADVANCED_MEDIAS_FOLDER'					=> 'Medien-Speicherort (Ordner)',
'L_CONFIG_ADVANCED_ARTS_FOLDER'						=> 'Artikelordner',
'L_CONFIG_ADVANCED_COMS_FOLDER'						=> 'Kommentarordner',
'L_CONFIG_ADVANCED_STATS_FOLDER'					=> 'Ordner für statische Seiten',
'L_CONFIG_ADVANCED_THEMES_FOLDER'					=> 'Themen Ordner',
'L_CONFIG_ADVANCED_PLUGINS_FOLDER'					=> 'Plugins Ordner',
'L_CONFIG_ADVANCED_CONFIG_FOLDER'					=> 'Ort der Konfigurationsdateien (Ordner)',
'L_CONFIG_ADVANCED_UPDATE'							=> 'Änderungen speichern',
'L_CONFIG_CUSTOM_CSSADMIN_PATH'						=> 'Standort und den Namen der benutzerdefinierten CSS-Datei des Verwaltungsbereich (optional)',
'L_CONFIG_BASE_CONFIG_TITLE'						=> 'Grundeinstellungen',
'L_CONFIG_BASE_SITE_TITLE'							=> 'Titel der Website',
'L_CONFIG_BASE_SITE_SLOGAN'							=> 'Untertitel/Beschreibung der Website',
'L_CONFIG_BASE_URL_HELP'							=> 'Schägstrich (Slash) am Ende nicht vergessen!',
'L_CONFIG_BASE_DEFAULT_LANG'						=> 'Standardsprache der Website',
'L_CONFIG_BASE_TIMEZONE'							=> 'Zeitzone',
'L_CONFIG_BASE_ALLOW_COMMENTS'						=> 'Kommentare erlaubt',
'L_CONFIG_BASE_MODERATE_COMMENTS'					=> 'Kommentare moderieren',
'L_CONFIG_BASE_MODERATE_ARTICLES'					=> 'Artikel moderieren/bearbeiten',
'L_CONFIG_BASE_UPDATE'								=> 'Grundeinstellungen speichern',
'L_CONFIG_META_DESCRIPTION'							=> 'META Tag "description" - Inhalt (optional)',
'L_CONFIG_META_KEYWORDS'							=> 'META Tag "keywords" - Inhalt (optional)',
'L_CONFIG_EDITTPL_ERROR_NOTHEME'					=> 'Dieses Thema existiert nicht!',
'L_CONFIG_EDITTPL_TITLE'							=> 'Thema editieren',
'L_CONFIG_EDITTPL_SELECT_FILE'						=> 'Wählen Sie die Datei, die Sie editieren wollen:',
'L_CONFIG_EDITTPL_LOAD'								=> 'Laden',
'L_CONFIG_INFOS_TITLE'								=> 'PluXml Systemnachrichten',
'L_CONFIG_INFOS_DESCRIPTION'						=> 'Systemstatus und nützliche Informationen zum Betrieb von PluXml',
'L_CONFIG_INFOS_NB_CATS'							=> 'Anzahl der Kategorien:',
'L_CONFIG_INFOS_NB_STATICS'							=> 'Anzahl der statischen Seiten:',
'L_CONFIG_INFOS_WRITER'								=> 'Benutzername der aktuellen SESSION:',
'L_PLUXML_CHECK_VERSION'							=> 'Aktualitätsprüfung von PluXml (über PluXml.org)',
'L_PLUXML_UPDATE_UNAVAILABLE'						=> 'Update hat nicht funktioniert. Sie sollten  \'allow_url_fopen\' aktivieren.',
'L_PLUXML_UPDATE_ERR'								=> 'Updatefunktion mit unbekanntem Fehler abgebrochen.',
'L_PLUXML_UPTODATE'									=> 'Sie benutzen die aktuellste Version von PluXml',
'L_PLUXML_UPDATE_AVAILABLE'							=> 'Eine neue Version ist verfügbar! Sie können sie hier herunterladen: ',
'L_CONFIG_USERS_TITLE'								=> 'Benutzerverwaltung',
'L_CONFIG_USER'										=> 'Benutzer',
'L_CONFIG_USERS_ID'									=> 'Benutzer-ID',
'L_CONFIG_USERS_ACTIVE'								=> 'Aktiv',
'L_CONFIG_USERS_ACTION'								=> 'Aktion',
'L_CONFIG_USERS_NEW'								=> 'Neuer Benutzer',
'L_CONFIG_USERS_UPDATE'								=> 'Änderungen speichern',
'L_ERR_LOGIN_ALREADY_EXISTS'						=> 'Diese Login-ID wird bereits verwendet',
'L_ERR_USERNAME_ALREADY_EXISTS'						=> 'Dieser Benutzername ist bereits vergeben',
'L_ERR_CATEGORY_ALREADY_EXISTS'						=> 'Dieser Kategoriename existiert bereits',
'L_ERR_STATIC_ALREADY_EXISTS'						=> 'wird bereits verwendet',
'L_BACK_TO_PLUGINS'									=> 'Zurück zur Plugins-Seite',
'L_NO_PLUGIN'										=> 'Keine Plugins',
'L_PLUGIN_NO_CONFIG'								=> 'Plugin nicht konfiguriert',
'L_PLUGINS_CSS'										=> 'CSS-Code',
'L_PLUGINS_CSS_TITLE'								=> 'Bearbeiten Sie den CSS-Code des Plugins',
'L_CONTENT_FIELD_FRONTEND'							=> 'CSS-Datei-Inhalte Website',
'L_CONTENT_FIELD_BACKEND'							=> 'CSS-Datei Content-Administrator',
'L_PLUGINS_TITLE'									=> 'Pluginverwaltung',
'L_PLUGINS_VERSION'									=> 'Version',
'L_PLUGINS_AUTHOR'									=> 'Autor',
'L_PLUGINS_ACTIVATE'								=> 'Aktivieren',
'L_PLUGINS_DEACTIVATE'								=> 'Deaktivieren',
'L_PLUGINS_DELETE'									=> 'Löschen',
'L_PLUGINS_DELETE_ERROR'							=> 'Löschen fehlgeschlagen',
'L_PLUGINS_DELETE_SUCCESSFUL'						=> 'Löschen war erfolgreich',
'L_PLUGINS_CONFIG'									=> 'Konfiguration',
'L_PLUGINS_CONFIG_TITLE'							=> 'Pluginkonfiguration',
'L_PLUGINS_REQUIREMENTS'							=> 'Voraussetzungen',
'L_PLUGINS_REQUIREMENTS_HELP'						=> 'Vorausgesetzte Plugins (installiert und aktiviert), damit dieses Plugin verwendet werden kann',
'L_PLUGINS_REQUIREMENTS_NONE'						=> 'Kein',
'L_PLUGINS_ALPHA_SORT'								=> 'Alphabetisch sortieren Plugins',
'L_PLUGINS_LOADING_SORT'							=> 'Geladen, um',
'L_PLUGINS_ACTION'									=> 'Aktion',
'L_PLUGINS_APPLY_BUTTON'							=> 'Ändern Sie die Liste der Plugins',
'L_PLUGINS_ACTIVE_LIST'								=> 'Aktive plugins',
'L_PLUGINS_INACTIVE_LIST'							=> 'Inaktive plugins',
'L_PROFIL_EDIT_TITLE'								=> 'Benutzerprofil bearbeiten',
'L_PROFIL'											=> 'Profil',
'L_PROFIL_LOGIN'									=> 'Login',
'L_PROFIL_USER'										=> 'Benutzername',
'L_PROFIL_MAIL'										=> 'E-Mail-Adresse',
'L_PROFIL_ADMIN_LANG'								=> 'Administration Sprache',
'L_PROFIL_INFOS'									=> 'Nachrichten',
'L_PROFIL_UPDATE'									=> 'Benutzerprofil speichern',
'L_PROFIL_CHANGE_PASSWORD'							=> 'Passwort ändern',
'L_PROFIL_PASSWORD'									=> 'Neues Passwort',
'L_PROFIL_CONFIRM_PASSWORD'							=> 'Neues Passwort wiederholen',
'L_PROFIL_UPDATE_PASSWORD'							=> 'Passwortänderung speichern',
'L_STATIC_BACK_TO_PAGE'								=> 'Zurück zur Liste',
'L_STATIC_UNKNOWN_PAGE'								=> 'Diese statische Seite existiert nicht oder nicht mehr!',
'L_STATIC_TITLE'									=> 'Quellcodes der statischen Seite editieren',
'L_STATIC_VIEW_PAGE'								=> 'Voransicht von',
'L_STATIC_ON_SITE'									=> 'im Frontend',
'L_STATIC_UPDATE'									=> 'Änderungen speichern',
'L_STATIC_TITLE_HTMLTAG'							=> 'Title-Tag Inhalte (optional)',
'L_STATIC_META_DESCRIPTION'							=> 'META Tag "description" - Inhalt für diese statische Seite (optional)',
'L_STATIC_META_KEYWORDS'							=> 'META Tag "keywords" - Inhalt für diese statische Seite (optional)',
'L_STATICS_PAGE_TITLE'								=> 'Statische Seiten erstellen/edtitieren',
'L_STATICS_ID'										=> 'ID',
'L_STATICS_GROUP'									=> 'Gruppe',
'L_STATICS_TITLE'									=> 'Titel',
'L_STATICS_URL'										=> 'URL',
'L_STATICS_ACTIVE'									=> 'Aktiv',
'L_STATICS_ORDER'									=> 'Sortierung',
'L_STATICS_MENU'									=> 'Menü',
'L_STATICS_ACTION'									=> 'Aktion',
'L_STATICS_TEMPLATE_FIELD'							=> 'Template',
'L_STATICS_PAGE_HOME'								=> 'Als Startseite',
'L_STATICS_HOME_PAGE'								=> 'Startseite',
'L_PAGE'											=> 'Seite',
'L_VIEW'											=> 'Ansehen',
'L_STATICS_SRC_TITLE'								=> 'Quellcode dieser Seite editieren',
'L_STATICS_SRC'										=> 'Ändern',
'L_STATICS_NEW_PAGE'								=> 'Neue Seite',
'L_STATICS_UPDATE'									=> 'Änderungen speichern',
'L_PROFIL_ADMIN'									=> 'Admin',
'L_PROFIL_MANAGER'									=> 'Manager',
'L_PROFIL_MODERATOR'								=> 'Moderator',
'L_PROFIL_EDITOR'									=> 'Redakteur',
'L_PROFIL_WRITER'									=> 'Autor',
'L_ADMIN'											=> '- Admin',
'L_LOGIN'											=> 'Angemeldet als ',
'L_ADMIN_LOGOUT'									=> 'Abmelden',
'L_ADMIN_LOGOUT_TITLE'								=> 'Administration beenden',
'L_BACK_TO_SITE'									=> 'Startseite',
'L_BACK_TO_SITE_TITLE'								=> 'Zurück zum startseite',
'L_BACK_TO_BLOG'									=> 'Blog',
'L_BACK_TO_BLOG_TITLE'								=> 'Zurück zum Blog',
'L_MENU_ARTICLES'									=> 'Artikel',
'L_MENU_ARTICLES_TITLE'								=> 'Artikelverwaltung',
'L_MENU_NEW_ARTICLES'								=> 'Neuer Artikel',
'L_MENU_NEW_ARTICLES_TITLE'							=> 'Neuer Artikel',
'L_MENU_STATICS_TITLE'								=> 'Statische Seiten Verwaltung',
'L_MENU_STATICS'									=> 'Statische Seiten',
'L_MENU_COMMENTS_TITLE'								=> 'Kommentarverwaltung',
'L_MENU_COMMENTS'									=> 'Kommentare',
'L_MENU_MEDIAS_TITLE'								=> 'Dateien hochladen und verwalten',
'L_MENU_MEDIAS'										=> 'Mediathek',
'L_MENU_CATEGORIES_TITLE'							=> 'Kategorieverwaltung',
'L_MENU_CATEGORIES'									=> 'Kategorien',
'L_MENU_CONFIG_TITLE'								=> 'PluXml Konfiguration',
'L_MENU_CONFIG'										=> 'Konfiguration',
'L_MENU_PROFIL_TITLE'								=> 'Mein Benutzerprofil verwalten',
'L_MENU_PROFIL'										=> 'Mein Profil',
'L_WARNING_INSTALLATION_FILE'						=> 'Die Datei install.php existiert noch im Grundverzeichnis von PluXml.<br />Sie sollten diese aus Sicherheitsgründen löschen.',
'L_USER_UNKNOWN'									=> 'Unbekannter Benutzer',
'L_USER_LANG'										=> 'Spracher des Admins',
'L_USER_MAIL'										=> 'E-Mail-Adresse',
'L_USER_INFOS'										=> 'Nachrichten',
'L_USER_UPDATE'										=> 'Benutzer aktualisieren',
'L_USER_PAGE_TITLE'									=> 'Benutzeroptionen bearbeiten',
'L_USER_BACK_TO_PAGE'								=> 'Zurück zur Benutzerliste',
'L_MENU_CONFIG_BASE_TITLE'							=> 'PluXml Grundeinstellungen bearbeiten',
'L_MENU_CONFIG_BASE'								=> 'Grundeinstellungen',
'L_MENU_CONFIG_VIEW_TITLE'							=> 'PluXml Anzeigeoptionen bearbeiten',
'L_MENU_CONFIG_VIEW'								=> 'Anzeigeoptionen',
'L_MENU_CONFIG_USERS_TITLE'							=> 'PluXml Benutzerverwaltung',
'L_MENU_CONFIG_USERS'								=> 'Benutzer',
'L_MENU_CONFIG_ADVANCED_TITLE'						=> 'PluXml Erweiterte Einstellungen bearbeiten',
'L_MENU_CONFIG_ADVANCED'							=> 'Erweiterte Einstellungen',
'L_MENU_CONFIG_INFOS_TITLE'							=> 'Sie haben Nachrichten von Ihrem PluXml',
'L_MENU_CONFIG_INFOS'								=> 'Nachrichten',
'L_MENU_CONFIG_PLUGINS_TITLE'						=> 'Plugins verwalten',
'L_MENU_CONFIG_PLUGINS'								=> 'Plugins',
'L_ERR_URL_ALREADY_EXISTS'							=> 'Url bereits im Einsatz. Bitte ändern Sie den Wert des Feldes \'Url\'',
'L_THEMES'											=> 'Themes',
'L_THEMES_TITLE'									=> 'Verwalten von Themen',
'L_HELP'											=> 'Hilfe',
'L_HELP_TITLE'										=> 'Siehe Hilfe',
'L_BACK_TO_THEMES'									=> 'Zurück Hilfe',
'L_ERR_INVALID_DATE_CREATION'						=> 'Ungültige Erstellungsdatum',
'L_ERR_INVALID_DATE_UPDATE'							=> 'Datum ungültig aktualisiert',	
);
?>